#!/usr/bin/env bash

set -o allexport
source "${PYTEST_ENVIRONMENT}"
set +o allexport

# NOTE: only set -x after sourcing secret values, otherwise they are leaked
set -u -x

echo "Using bucket:"
echo $PREPROCESSOR_RESULTS_BUCKET

TEST_RESULT=0


# wait as in registrar_prep.sh, not sure if necessary
kubectl exec deployment/my-helm-release-registrar -- ./wait-initialized.sh
kubectl exec deployment/my-helm-release-renderer -- ./wait-initialized.sh

# preprocessor
cat preprocessed_list.csv | while read product ; do
    echo $product
    kubectl exec deployment/my-helm-release-preprocessor -- preprocessor preprocess --config-file /config.yaml "$product"
done

# registrar
jq -c '.[]' product_list.json | while read product_stac_json ; do
    echo $product_stac_json
    kubectl exec deployment/my-helm-release-registrar -- registrar register --config-file /config.yaml "${product_stac_json}"
done

# copy registrar result here to inspect it in test
kubectl cp default/`kubectl get po -l app.kubernetes.io/name=registrar -o name | cut -d'/' -f2 `:/mnt/ /mnt/registrar

# run tests (i.e. verification of output of above commands)
kubectl port-forward svc/my-helm-release-database 5432:5432 &
KUBECTL_PORT_FORWARD_PID=$!

pytest test_preprocessor.py test_registrar.py
let "TEST_RESULT+=$?"

swift delete "${PREPROCESSOR_RESULTS_BUCKET}"
swift delete "${PREPROCESSOR_RESULTS_BUCKET}_segments"


# NOTE: ingestion tests should look something like this:
#       we need to run the ingestor with watch mode, which is not possible at this point
# kubectl cp ./tpzonlineitem.xml newvs/vshr-ingestor-5d7fc45858-4zsrk:/mnt/data/tpzonlineitem.xml
# kubectl cp ./defected_report.xml newvs/vshr-ingestor-5d7fc45858-4zsrk:/mnt/data/defected_report.xml
# sleep 80  # run ingestor
# kubectl exec deployment/vshr-ingestor -- ls /var/ingestor/success > success_list.csv
# kubectl exec deployment/vshr-ingestor -- ls /var/ingestor/fail > failure_list.csv
# sleep 10  # not sure why we wait here?
# pytest test_ingestor.py
# let "TEST_RESULT+=$?"



kill $KUBECTL_PORT_FORWARD_PID

exit $TEST_RESULT
